package com.armundia.adv360.bes.startup;

import java.util.logging.Formatter;
import java.util.logging.LogRecord;
import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;

public class CustomLogFormatter extends Formatter {
    
    private static final DateTimeFormatter dateFormatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss,SSS");

    private String stripXMLTags(String input) {
        if (input == null || input.isEmpty()) {
            return input;
        }
        return input.replaceAll("<[^>]*>", "");
    }

    @Override
    public String format(LogRecord record) {
        StringBuilder sb = new StringBuilder();
        
        // Data e ora
        sb.append(ZonedDateTime.now().format(dateFormatter))
          .append(" ");
        
        // Livello log padded a 5 caratteri
        String level = record.getLevel().toString();
        sb.append(String.format("%-5s", level));
        
        // Nome classe
        sb.append("[")
          .append(record.getSourceClassName())
          .append("] ");
        
        // Thread
        sb.append("(")
          .append(Thread.currentThread().getName())
          .append(") ");
        
        // Messaggio
        String message = formatMessage(record);
        sb.append(stripXMLTags(message));
        
        // Stack trace se presente
        if (record.getThrown() != null) {
            sb.append("\n");
            for (StackTraceElement element : record.getThrown().getStackTrace()) {
                sb.append("\tat ")
                  .append(element.toString())
                  .append("\n");
            }
        }
        
        sb.append("\n");
        return sb.toString();
    }
}
